============
Installation
============

At the command line either via easy_install or pip::

    $ easy_install my_checker
    $ pip install my_checker

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv my_checker
    $ pip install my_checker
